@@ -1,5 +1,5 @@
 document.getElementById("Contents").innerHTML='\
-    <ul><li><input type="checkbox" id="07"><label for="07">Makron och programmering</label><ul>\
+    <ul><li><input type="checkbox" id="07"><label for="07">Makron och skripting</label><ul>\
     <li><input type="checkbox" id="0701"><label for="0701">Allmän information och användning av användargränssnitt </label><ul>\
     <li><a target="_top" href="sv/text/sbasic/shared/main0601.html">Hjälp för LibreOffice Basic</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/01000000.html">Programmera med LibreOffice Basic</a></li>\
@@ -17,7 +17,7 @@ document.getElementById("Contents").innerHTML='\
     <li><input type="checkbox" id="0702"><label for="0702">Kommandoreferens</label><ul>\
     <li><a target="_top" href="sv/text/sbasic/shared/01020300.html">Använda procedurer och funktioner</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/01020500.html">Bibliotek, moduler och dialogrutor</a></li>\
-    <li><input type="checkbox" id="070202"><label for="070202">Functions, Statements, and Operators</label><ul>\
+    <li><input type="checkbox" id="070202"><label for="070202">Funktioner, uttryck och operatorer</label><ul>\
     <li><a target="_top" href="sv/text/sbasic/shared/03010000.html">In- och utmatningsfunktioner för bildskärm</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03020000.html">In- och utmatningsfunktioner för filer</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03030000.html">Datum- och tidsfunktioner</a></li>\
@@ -41,7 +41,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/sbasic/shared/03120111.html">AscW Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03080101.html">Atn Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03130100.html">Beep Statement</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03010301.html">Blue Function</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03010301.html">Blå funktion</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03100100.html">CBool Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03120105.html">CByte Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03100050.html">CCur Function</a></li>\
@@ -61,12 +61,12 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/sbasic/shared/03100900.html">CSng Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03101000.html">CStr Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03090401.html">Call Statement</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020401.html">ChDir Statement</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020402.html">ChDrive Statement</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020401.html">ChDir-uttryck</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020402.html">ChDrive-uttryck</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03090402.html">Choose Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03120102.html">Chr Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03120112.html">ChrW Function [VBA]</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020101.html">Close Statement</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020101.html">Stäng uttryck</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03110100.html">Comparison Operators</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03100700.html">Const Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03120313.html">ConvertFromURL Function</a></li>\
@@ -78,7 +78,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/sbasic/shared/03131600.html">CreateUnoService Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03131500.html">CreateUnoStruct Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03132300.html">CreateUnoValue Function</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020403.html">CurDir Function</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020403.html">CurDir-funktion</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03100070.html">CVar Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03100080.html">CVErr Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03030110.html">DateAdd Function</a></li>\
@@ -99,12 +99,12 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/sbasic/shared/03102000.html">DefVar Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03104300.html">DimArray Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03102100.html">Dim Statement</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020404.html">Dir Function</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020404.html">Dir-funktion</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03090201.html">Do...Loop Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03110100.html">Comparison Operators</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03090404.html">End Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03130800.html">Environ Function</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020301.html">Eof Function</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020301.html">Eof-funktion</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03104600.html">EqualUnoObjects Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03060200.html">Eqv Operator</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03050100.html">Erl Function</a></li>\
@@ -113,7 +113,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/sbasic/shared/03050000.html">Felhanteringsfunktioner</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03090412.html">Exit Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03080201.html">Exp Function</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020405.html">FileAttr Function</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020405.html">FileAttr-funktion</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03020406.html">FileCopy Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03020407.html">FileDateTime Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03020415.html">FileExists Function</a></li>\
@@ -124,7 +124,8 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/sbasic/shared/03090202.html">For...Next Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03120301.html">Format Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03150000.html">FormatDateTime Function [VBA]</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020102.html">FreeFile Function</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03170010.html">FormatNumber Function [VBA]</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020102.html">FreeFile-funktion</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03090405.html">FreeLibrary Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03090406.html">Function Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03090400.html">Ytterligare uttryck</a></li>\
@@ -136,11 +137,11 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/sbasic/shared/03131700.html">GetProcessServiceManager Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03131000.html">GetSolarVersion Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03130700.html">GetSystemTicks Function</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020201.html">Get Statement</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020201.html">Hämta uttryck</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03131900.html">GlobalScope</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03090301.html">GoSub...Return Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03090302.html">GoTo Statement</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03010302.html">Green Function</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03010302.html">Grön funktion</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03104400.html">HasUnoInterfaces Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03080801.html">Hex Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03030201.html">Hour Function</a></li>\
@@ -150,8 +151,8 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/sbasic/shared/03120401.html">InStr Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03120411.html">InStrRev Function [VBA]</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03160000.html">Input Function [VBA]</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03010201.html">InputBox Function</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020202.html">Input# Statement</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03010201.html">InputBox-funktion</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020202.html">Inmatnings# Uttryck</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03080502.html">Int Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03140002.html">IPmt Function [VBA]</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03140003.html">IRR Function [VBA]</a></li>\
@@ -172,9 +173,9 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/sbasic/shared/03120303.html">Left Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03120402.html">Len Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03103100.html">Let Statement</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020203.html">Line Input # Statement</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020302.html">Loc Function</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020303.html">Lof Function</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020203.html">Radinmatnings # Uttryck</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020302.html">Loc-funktion</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020303.html">Lof-funktion</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03080202.html">Log Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03120306.html">Mid Function, Mid Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03030202.html">Minute Function</a></li>\
@@ -183,8 +184,8 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/sbasic/shared/03070600.html">Mod Operator</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03030104.html">Month Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03150002.html">MonthName Function [VBA]</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03010102.html">MsgBox Function</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03010101.html">MsgBox Statement</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03010102.html">MsgBox-Funktion</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03010101.html">MsgBox-uttryck</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03020412.html">Name Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03060400.html">Not Operator</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03030203.html">Now Function</a></li>\
@@ -194,7 +195,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/sbasic/shared/03080802.html">Oct Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03050500.html">On Error GoTo ... Resume Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03090303.html">On...GoSub Statement; On...GoTo Statement</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020103.html">Open Statement</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020103.html">Öppna uttryck</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03103200.html">Option Base Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03103300.html">Option Explicit Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03103350.html">Option VBASupport Statement</a></li>\
@@ -205,24 +206,24 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/sbasic/shared/03140009.html">PV Function [VBA]</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03010103.html">Print Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03103400.html">Public Statement</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020204.html">Put Statement</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03010304.html">QBColor Function</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020204.html">Ställ uttryck</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03010304.html">QB-färg funktion</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03140010.html">Rate Function [VBA]</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03010305.html">RGB Function</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03010305.html">RGB-funktion</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03120308.html">RSet Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03120309.html">RTrim Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03080301.html">Randomize Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03102101.html">ReDim Statement</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03010303.html">Red Function</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03010303.html">Röd funktion</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03090407.html">Rem Statement</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020104.html">Reset Statement</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020104.html">Återställ uttryck</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03120307.html">Right Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03020413.html">RmDir Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03080302.html">Rnd Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03170000.html">Round Function [VBA]</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03030204.html">Second Function</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020304.html">Seek Function</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020305.html">Seek Statement</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020304.html">Sök funktion</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020305.html">Sök uttryck</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03090102.html">Select...Case Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03020414.html">SetAttr Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03103700.html">Set Statement</a></li>\
@@ -262,7 +263,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/sbasic/shared/03150001.html">WeekdayName Function [VBA]</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03090203.html">While...Wend Statement</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03090411.html">With Statement</a></li>\
-    <li><a target="_top" href="sv/text/sbasic/shared/03020205.html">Write Statement</a></li>\
+    <li><a target="_top" href="sv/text/sbasic/shared/03020205.html">Skrivuttryck</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03060600.html">XOR Operator</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03030106.html">Year Function</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03070100.html">"-" Operator</a></li>\
@@ -271,7 +272,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/sbasic/shared/03070400.html">"/" Operator</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03070500.html">"^" Operator</a></li>\
 			</ul></li>\
-    <li><input type="checkbox" id="070205"><label for="070205">Advanced Basic Libraries</label><ul>\
+    <li><input type="checkbox" id="070205"><label for="070205">Avancerade grundläggande bibliotek</label><ul>\
     <li><a target="_top" href="sv/text/sbasic/shared/03/lib_tools.html">Tools Library</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03/lib_depot.html">DEPOT Library</a></li>\
     <li><a target="_top" href="sv/text/sbasic/shared/03/lib_euro.html">EURO Library</a></li>\
@@ -297,7 +298,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/sbasic/guide/access2base.html">Access2Base</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="08"><label for="08">Kalkylblad</label><ul>\
+    <ul><li><input type="checkbox" id="08"><label for="08">Kalkylark (Calc)</label><ul>\
     <li><input type="checkbox" id="0801"><label for="0801">Allmän information och användning av användargränssnitt </label><ul>\
     <li><a target="_top" href="sv/text/scalc/main0000.html">Välkommen till LibreOffice Calc-hjälpen</a></li>\
     <li><a target="_top" href="sv/text/scalc/main0503.html">LibreOffice Calc-funktioner</a></li>\
@@ -419,7 +420,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/scalc/guide/datapilot_tipps.html">Välja var pivottabellen placeras</a></li>\
     <li><a target="_top" href="sv/text/scalc/guide/datapilot_updatetable.html">Uppdatera pivottabeller</a></li>\
 		</ul></li>\
-    <li><input type="checkbox" id="08091"><label for="08091">Pivot Chart</label><ul>\
+    <li><input type="checkbox" id="08091"><label for="08091">Pivotdiagram</label><ul>\
     <li><a target="_top" href="sv/text/scalc/guide/pivotchart.html">Pivot Chart</a></li>\
     <li><a target="_top" href="sv/text/scalc/guide/pivotchart_create.html">Creating Pivot Charts</a></li>\
     <li><a target="_top" href="sv/text/scalc/guide/pivotchart_edit.html">Editing Pivot Charts</a></li>\
@@ -477,7 +478,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/schart/04/01020000.html">Kortkommandon för diagram</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="01"><label for="01">Installation</label><ul>\
+    <ul><li><input type="checkbox" id="01"><label for="01">LibreOffice installation</label><ul>\
     <li><a target="_top" href="sv/text/shared/guide/ms_doctypes.html">Ändra associationen till dokumenttyper i Microsoft Office</a></li>\
     <li><a target="_top" href="sv/text/shared/01/profile_safe_mode.html">Felsäkert läge</a></li>\
 	</ul></li></ul>\
@@ -503,7 +504,6 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/shared/optionen/01010200.html">Allmänt</a></li>\
     <li><a target="_top" href="sv/text/shared/optionen/01010300.html">Sökvägar</a></li>\
     <li><a target="_top" href="sv/text/shared/optionen/01010400.html">Lingvistik</a></li>\
-    <li><a target="_top" href="sv/text/shared/optionen/01010500.html">Color</a></li>\
     <li><a target="_top" href="sv/text/shared/optionen/01010600.html">Allmänt</a></li>\
     <li><a target="_top" href="sv/text/shared/optionen/01010700.html">Teckensnitt</a></li>\
     <li><a target="_top" href="sv/text/shared/optionen/01010800.html">Visa</a></li>\
@@ -567,7 +567,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/shared/guide/textmode_change.html">Växla mellan infognings- och överskrivningsläge</a></li>\
     <li><a target="_top" href="sv/text/shared/guide/floating_toolbar.html">Använda verktygsrader</a></li>\
 		</ul></li>\
-    <li><input type="checkbox" id="10071"><label for="10071">Digital Signatures</label><ul>\
+    <li><input type="checkbox" id="10071"><label for="10071">Digitala signaturer</label><ul>\
     <li><a target="_top" href="sv/text/shared/guide/digital_signatures.html">Om digitala signaturer</a></li>\
     <li><a target="_top" href="sv/text/shared/guide/digitalsign_send.html">Använda digitala signaturer</a></li>\
     <li><a target="_top" href="sv/text/shared/01/digitalsignaturespdf.html">Digital Signature in PDF Export</a></li>\
@@ -661,7 +661,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/shared/guide/numbering_stop.html">Stänga av punktuppställningstecken för enskilda stycken</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="09"><label for="09">Databasfunktionalitet</label><ul>\
+    <ul><li><input type="checkbox" id="09"><label for="09">Databasfunktionalitet (Base)</label><ul>\
     <li><input type="checkbox" id="0901"><label for="0901">Allmän information</label><ul>\
     <li><a target="_top" href="sv/text/shared/explorer/database/main.html">LibreOffice-databas</a></li>\
     <li><a target="_top" href="sv/text/shared/guide/database_main.html">Databasöversikt</a></li>\
@@ -675,7 +675,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/shared/guide/data_enter_sql.html">Köra SQL-kommandon</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="04"><label for="04">Presentationer och teckningar</label><ul>\
+    <ul><li><input type="checkbox" id="04"><label for="04">Presentationer och ritningar (Impress/Draw)</label><ul>\
     <li><input type="checkbox" id="0401"><label for="0401">Allmän information och användning av användargränssnitt </label><ul>\
     <li><a target="_top" href="sv/text/simpress/main0000.html">Välkommen till LibreOffice Impress-hjälpen</a></li>\
     <li><a target="_top" href="sv/text/sdraw/main0000.html">Välkommen till LibreOffice Draw-hjälpen</a></li>\
@@ -698,7 +698,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/simpress/main0103.html">Vy</a></li>\
     <li><a target="_top" href="sv/text/simpress/main0104.html">Infoga</a></li>\
     <li><a target="_top" href="sv/text/simpress/main0105.html">Format</a></li>\
-    <li><a target="_top" href="sv/text/simpress/main0117.html">Slide</a></li>\
+    <li><a target="_top" href="sv/text/simpress/main0117.html">Bild</a></li>\
     <li><a target="_top" href="sv/text/simpress/main0114.html">Bildskärmspresentation</a></li>\
     <li><a target="_top" href="sv/text/simpress/main0106.html">Verktyg</a></li>\
     <li><a target="_top" href="sv/text/simpress/main0107.html">Fönster</a></li>\
@@ -715,7 +715,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/simpress/main0211.html">Verktygsraden Disposition</a></li>\
     <li><a target="_top" href="sv/text/simpress/main0212.html">Verktygsraden Bildsortering</a></li>\
     <li><a target="_top" href="sv/text/simpress/main0213.html">Verktygsraden Alternativ</a></li>\
-    <li><a target="_top" href="sv/text/simpress/main0214.html">Image Bar</a></li>\
+    <li><a target="_top" href="sv/text/simpress/main0214.html">Verktygsraden Bild</a></li>\
     <li><a target="_top" href="sv/text/shared/main0201.html">Standardrad</a></li>\
     <li><a target="_top" href="sv/text/shared/main0213.html">Verktygsraden Formulär</a></li>\
     <li><a target="_top" href="sv/text/shared/main0226.html">Verktygsraden Formulärdesign</a></li>\
@@ -812,7 +812,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/simpress/guide/arrange_slides.html">Ändra bildordningen</a></li>\
     <li><a target="_top" href="sv/text/simpress/guide/change_scale.html">Zooma med tangentbordet</a></li>\
          </ul></li>\
-    <li><input type="checkbox" id="0411"><label for="0411">Slide Shows</label><ul>\
+    <li><input type="checkbox" id="0411"><label for="0411">Bildspel</label><ul>\
     <li><a target="_top" href="sv/text/simpress/guide/show.html">Visar bilderna</a></li>\
     <li><a target="_top" href="sv/text/simpress/guide/presenter_console.html">Using the Presenter Console</a></li>\
     <li><a target="_top" href="sv/text/simpress/guide/impress_remote.html">Impress Remote Guide</a></li>\
@@ -820,7 +820,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/simpress/guide/rehearse_timings.html">Visa en presentation med tidtagning</a></li>\
          </ul></li>\
      </ul></li></ul>\
-    <ul><li><input type="checkbox" id="03"><label for="03">Formler</label><ul>\
+    <ul><li><input type="checkbox" id="03"><label for="03">Formler (Math)</label><ul>\
     <li><input type="checkbox" id="0301"><label for="0301">Allmän information och användning av användargränssnitt </label><ul>\
     <li><a target="_top" href="sv/text/smath/main0000.html">Välkommen till LibreOffice Math-hjälpen</a></li>\
     <li><a target="_top" href="sv/text/smath/main0503.html">Funktioner i LibreOffice Math</a></li>\
@@ -840,7 +840,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/smath/guide/parentheses.html">Infoga parentes</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="02"><label for="02">Textdokument</label><ul>\
+    <ul><li><input type="checkbox" id="02"><label for="02">Textdokument (Writer)</label><ul>\
     <li><input type="checkbox" id="0201"><label for="0201">Allmän information och användning av användargränssnitt </label><ul>\
     <li><a target="_top" href="sv/text/swriter/main0000.html">Välkommen till LibreOffice Writer-hjälpen</a></li>\
     <li><a target="_top" href="sv/text/swriter/main0503.html">Funktioner i LibreOffice Writer</a></li>\
@@ -1049,7 +1049,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="sv/text/shared/01/02100001.html">Lista med reguljära uttryck</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="06"><label for="06">HTML-dokument</label><ul>\
+    <ul><li><input type="checkbox" id="06"><label for="06">HTML-dokument (Writer Web)</label><ul>\
     <li><a target="_top" href="sv/text/shared/07/09000000.html">Webbsidor</a></li>\
     <li><a target="_top" href="sv/text/shared/02/01170700.html">HTML-filter och -formulär</a></li>\
     <li><a target="_top" href="sv/text/swriter/guide/send2html.html">Spara textdokument i HTML-format</a></li>\
